<a id="mypy-boto3-ds"></a>

# mypy-boto3-ds

[![PyPI - types-aiobotocore-ds](https://img.shields.io/pypi/v/types-aiobotocore-ds.svg?color=blue)](https://pypi.org/project/types-aiobotocore-ds)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-ds.svg?color=blue)](https://pypi.org/project/types-aiobotocore-ds)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-ds?color=blue)](https://pypistats.org/packages/types-aiobotocore-ds)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.DirectoryService 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ds.html#DirectoryService)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-ds docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_ds/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-ds](#mypy-boto3-ds)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `DirectoryService`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `DirectoryService` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[ds]'

# Lite version does not provide session.create_client overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[ds]'

# standalone installation
python -m pip install types-aiobotocore-ds
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[ds]` in your environment:
  `python -m pip install 'types-aiobotocore[ds]'`

Both type checking and auto-complete should work for `DirectoryService`
service. No explicit type annotations required, write your `boto3` code as
usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[ds]` in your environment:
  `python -m pip install 'types-aiobotocore[ds]'`

Both type checking and auto-complete should work for `DirectoryService`
service. No explicit type annotations required, write your `aiobotocore` code
as usual. Auto-complete can be slow on big projects or if you have a lot of
installed `types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[ds]` in your environment:
  `python -m pip install 'types-aiobotocore[ds]'`
- Run `mypy` as usual

Type checking should work for `DirectoryService` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[ds]` in your environment:
  `python -m pip install 'types-aiobotocore[ds]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `DirectoryService` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`DirectoryServiceClient` provides annotations for
`session.create_client("ds")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_ds import DirectoryServiceClient

session = get_session()
async with session.create_client("ds") as client:
    client: DirectoryServiceClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_ds.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_ds import DirectoryServiceClient
from types_aiobotocore_ds.paginator import (
    DescribeDirectoriesPaginator,
    DescribeDomainControllersPaginator,
    DescribeSharedDirectoriesPaginator,
    DescribeSnapshotsPaginator,
    DescribeTrustsPaginator,
    ListIpRoutesPaginator,
    ListLogSubscriptionsPaginator,
    ListSchemaExtensionsPaginator,
    ListTagsForResourcePaginator,
)

session = get_session()
async with session.create_client("ds") as client:
    client: DirectoryServiceClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_directories_paginator: DescribeDirectoriesPaginator = client.get_paginator("describe_directories")
        describe_domain_controllers_paginator: DescribeDomainControllersPaginator = client.get_paginator("describe_domain_controllers")
        describe_shared_directories_paginator: DescribeSharedDirectoriesPaginator = client.get_paginator("describe_shared_directories")
        describe_snapshots_paginator: DescribeSnapshotsPaginator = client.get_paginator("describe_snapshots")
        describe_trusts_paginator: DescribeTrustsPaginator = client.get_paginator("describe_trusts")
        list_ip_routes_paginator: ListIpRoutesPaginator = client.get_paginator("list_ip_routes")
        list_log_subscriptions_paginator: ListLogSubscriptionsPaginator = client.get_paginator("list_log_subscriptions")
        list_schema_extensions_paginator: ListSchemaExtensionsPaginator = client.get_paginator("list_schema_extensions")
        list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
    ```







### Literals

`types_aiobotocore_ds.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_ds.literals import (
    CertificateStateType,
    CertificateTypeType,
    ClientAuthenticationStatusType,
    ClientAuthenticationTypeType,
    DescribeDirectoriesPaginatorName,
    DescribeDomainControllersPaginatorName,
    DescribeSharedDirectoriesPaginatorName,
    DescribeSnapshotsPaginatorName,
    DescribeTrustsPaginatorName,
    DirectoryEditionType,
    DirectorySizeType,
    DirectoryStageType,
    DirectoryTypeType,
    DomainControllerStatusType,
    IpRouteStatusMsgType,
    LDAPSStatusType,
    LDAPSTypeType,
    ListIpRoutesPaginatorName,
    ListLogSubscriptionsPaginatorName,
    ListSchemaExtensionsPaginatorName,
    ListTagsForResourcePaginatorName,
    RadiusAuthenticationProtocolType,
    RadiusStatusType,
    RegionTypeType,
    ReplicationScopeType,
    SchemaExtensionStatusType,
    SelectiveAuthType,
    ShareMethodType,
    ShareStatusType,
    SnapshotStatusType,
    SnapshotTypeType,
    TargetTypeType,
    TopicStatusType,
    TrustDirectionType,
    TrustStateType,
    TrustTypeType,
    ServiceName,
    PaginatorName,
)

def check_value(value: CertificateStateType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_ds.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_ds.type_defs import (
    AcceptSharedDirectoryRequestRequestTypeDef,
    AcceptSharedDirectoryResultTypeDef,
    AddIpRoutesRequestRequestTypeDef,
    AddRegionRequestRequestTypeDef,
    AddTagsToResourceRequestRequestTypeDef,
    AttributeTypeDef,
    CancelSchemaExtensionRequestRequestTypeDef,
    CertificateInfoTypeDef,
    CertificateTypeDef,
    ClientAuthenticationSettingInfoTypeDef,
    ClientCertAuthSettingsTypeDef,
    ComputerTypeDef,
    ConditionalForwarderTypeDef,
    ConnectDirectoryRequestRequestTypeDef,
    ConnectDirectoryResultTypeDef,
    CreateAliasRequestRequestTypeDef,
    CreateAliasResultTypeDef,
    CreateComputerRequestRequestTypeDef,
    CreateComputerResultTypeDef,
    CreateConditionalForwarderRequestRequestTypeDef,
    CreateDirectoryRequestRequestTypeDef,
    CreateDirectoryResultTypeDef,
    CreateLogSubscriptionRequestRequestTypeDef,
    CreateMicrosoftADRequestRequestTypeDef,
    CreateMicrosoftADResultTypeDef,
    CreateSnapshotRequestRequestTypeDef,
    CreateSnapshotResultTypeDef,
    CreateTrustRequestRequestTypeDef,
    CreateTrustResultTypeDef,
    DeleteConditionalForwarderRequestRequestTypeDef,
    DeleteDirectoryRequestRequestTypeDef,
    DeleteDirectoryResultTypeDef,
    DeleteLogSubscriptionRequestRequestTypeDef,
    DeleteSnapshotRequestRequestTypeDef,
    DeleteSnapshotResultTypeDef,
    DeleteTrustRequestRequestTypeDef,
    DeleteTrustResultTypeDef,
    DeregisterCertificateRequestRequestTypeDef,
    DeregisterEventTopicRequestRequestTypeDef,
    DescribeCertificateRequestRequestTypeDef,
    DescribeCertificateResultTypeDef,
    DescribeClientAuthenticationSettingsRequestRequestTypeDef,
    DescribeClientAuthenticationSettingsResultTypeDef,
    DescribeConditionalForwardersRequestRequestTypeDef,
    DescribeConditionalForwardersResultTypeDef,
    DescribeDirectoriesRequestRequestTypeDef,
    DescribeDirectoriesResultTypeDef,
    DescribeDomainControllersRequestRequestTypeDef,
    DescribeDomainControllersResultTypeDef,
    DescribeEventTopicsRequestRequestTypeDef,
    DescribeEventTopicsResultTypeDef,
    DescribeLDAPSSettingsRequestRequestTypeDef,
    DescribeLDAPSSettingsResultTypeDef,
    DescribeRegionsRequestRequestTypeDef,
    DescribeRegionsResultTypeDef,
    DescribeSharedDirectoriesRequestRequestTypeDef,
    DescribeSharedDirectoriesResultTypeDef,
    DescribeSnapshotsRequestRequestTypeDef,
    DescribeSnapshotsResultTypeDef,
    DescribeTrustsRequestRequestTypeDef,
    DescribeTrustsResultTypeDef,
    DirectoryConnectSettingsDescriptionTypeDef,
    DirectoryConnectSettingsTypeDef,
    DirectoryDescriptionTypeDef,
    DirectoryLimitsTypeDef,
    DirectoryVpcSettingsDescriptionTypeDef,
    DirectoryVpcSettingsTypeDef,
    DisableClientAuthenticationRequestRequestTypeDef,
    DisableLDAPSRequestRequestTypeDef,
    DisableRadiusRequestRequestTypeDef,
    DisableSsoRequestRequestTypeDef,
    DomainControllerTypeDef,
    EnableClientAuthenticationRequestRequestTypeDef,
    EnableLDAPSRequestRequestTypeDef,
    EnableRadiusRequestRequestTypeDef,
    EnableSsoRequestRequestTypeDef,
    EventTopicTypeDef,
    GetDirectoryLimitsResultTypeDef,
    GetSnapshotLimitsRequestRequestTypeDef,
    GetSnapshotLimitsResultTypeDef,
    IpRouteInfoTypeDef,
    IpRouteTypeDef,
    LDAPSSettingInfoTypeDef,
    ListCertificatesRequestRequestTypeDef,
    ListCertificatesResultTypeDef,
    ListIpRoutesRequestRequestTypeDef,
    ListIpRoutesResultTypeDef,
    ListLogSubscriptionsRequestRequestTypeDef,
    ListLogSubscriptionsResultTypeDef,
    ListSchemaExtensionsRequestRequestTypeDef,
    ListSchemaExtensionsResultTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResultTypeDef,
    LogSubscriptionTypeDef,
    OwnerDirectoryDescriptionTypeDef,
    PaginatorConfigTypeDef,
    RadiusSettingsTypeDef,
    RegionDescriptionTypeDef,
    RegionsInfoTypeDef,
    RegisterCertificateRequestRequestTypeDef,
    RegisterCertificateResultTypeDef,
    RegisterEventTopicRequestRequestTypeDef,
    RejectSharedDirectoryRequestRequestTypeDef,
    RejectSharedDirectoryResultTypeDef,
    RemoveIpRoutesRequestRequestTypeDef,
    RemoveRegionRequestRequestTypeDef,
    RemoveTagsFromResourceRequestRequestTypeDef,
    ResetUserPasswordRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    RestoreFromSnapshotRequestRequestTypeDef,
    SchemaExtensionInfoTypeDef,
    ShareDirectoryRequestRequestTypeDef,
    ShareDirectoryResultTypeDef,
    ShareTargetTypeDef,
    SharedDirectoryTypeDef,
    SnapshotLimitsTypeDef,
    SnapshotTypeDef,
    StartSchemaExtensionRequestRequestTypeDef,
    StartSchemaExtensionResultTypeDef,
    TagTypeDef,
    TrustTypeDef,
    UnshareDirectoryRequestRequestTypeDef,
    UnshareDirectoryResultTypeDef,
    UnshareTargetTypeDef,
    UpdateConditionalForwarderRequestRequestTypeDef,
    UpdateNumberOfDomainControllersRequestRequestTypeDef,
    UpdateRadiusRequestRequestTypeDef,
    UpdateTrustRequestRequestTypeDef,
    UpdateTrustResultTypeDef,
    VerifyTrustRequestRequestTypeDef,
    VerifyTrustResultTypeDef,
)

def get_structure() -> AcceptSharedDirectoryRequestRequestTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-ds` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-ds docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_ds/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
